/*
 * Copyright 2014 Decebal Suiu
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this work except in compliance with
 * the License. You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package ro.fortsoft.pippo.demo.crud;

import ro.fortsoft.pippo.core.Application;
import ro.fortsoft.pippo.core.Request;
import ro.fortsoft.pippo.core.Response;
import ro.fortsoft.pippo.core.RouteHandler;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Decebal Suiu
 */
public class CrudApplication extends Application {

    private ContactService contactService;

    @Override
    public void init() {
        super.init();

        /*
        FreemarkerTemplateEngine templateEngine = new FreemarkerTemplateEngine();
        try {
            templateEngine.getConfiguration().setDirectoryForTemplateLoading(new File("src/main/resources/templates/"));
        } catch (IOException e) {
            throw new PippoRuntimeException(e);
        }
        setTemplateEngine(templateEngine);
        */

        contactService = new InMemoryContactService();

        GET("/", new RouteHandler() {

            @Override
            public void handle(Request request, Response response) {
                response.redirect("/contacts");
            }

        });

        GET("/contacts", new RouteHandler() {

            @Override
            public void handle(Request request, Response response) {
                Map<String, Object> model = new HashMap<String, Object>();
                model.put("contacts", contactService.getContacts());
                response.render("crud/contacts.ftl", model);
            }

        });

        GET("/contact/:id", new RouteHandler() {

            @Override
            public void handle(Request request, Response response) {
                String action = request.getParameter("action").toString("new");
                int id = request.getParameter("id").toInt(0);
                if ("delete".equals(action)) {
                    contactService.delete(id);
                    response.redirect("/contacts");
                } else {
                    Contact contact = (id > 0) ? contactService.getContact(id) : new Contact();
                    Map<String, Object> model = new HashMap<String, Object>();
                    model.put("contact", contact);
                    StringBuilder editAction = new StringBuilder();
                    editAction.append("/contact?action=save");
                    if (id > 0) {
                        editAction.append("&id=");
                        editAction.append(id);
                    }
                    model.put("editAction", editAction);
                    model.put("backAction", "/contacts");
                    response.render("crud/contact.ftl", model);
                }
            }

        });

        POST("/contact", new RouteHandler() {

            @Override
            public void handle(Request request, Response response) {
                String action = request.getParameter("action").toString();
                if ("save".equals(action)) {
                    Contact contact = new Contact();
                    contact.setId(request.getParameter("id").toInt(-1));
                    contact.setName(request.getParameter("name").toString());
                    contact.setPhone(request.getParameter("phone").toString());
                    contact.setAddress(request.getParameter("address").toString());
                    contactService.save(contact);
                    response.redirect("/contacts");
                }
            }

        });

    }

}
